@@ -6,7 +6,7 @@
 //!
 //! ```toml
 //! [dependencies.ldap3]
-//! version = "0.10.5"
+//! version = "0.11.5"
 //! ```
 //!
 //! ## Summary
@@ -20,7 +20,9 @@
 //! the short description.
 //!
 //! The documentation is written for readers familiar with LDAP concepts and terminology,
-//! which it won't attempt to explain.
+//! which it won't attempt to explain. If you need an introductory text, you can try the
+//! [primer](https://github.com/inejge/ldap3/blob/27a247c8a6e4e2c86f664f4280c4c6499f0e9fe5/LDAP-primer.md)
+//! included in this library.
 //!
 //! ## Compile-time features
 //!
@@ -99,8 +101,6 @@
 
 #![cfg_attr(docsrs, feature(doc_cfg))]
 
-#[macro_use]
-extern crate nom;
 #[doc(hidden)]
 #[macro_use]
 pub extern crate log;
@@ -192,7 +192,8 @@ pub mod controls {
         Assertion, ManageDsaIt, MatchedValues, PagedResults, ProxyAuth, RelaxRules,
     };
     pub use crate::controls_impl::{
-        Control, ControlParser, ControlType, CriticalControl, MakeCritical, RawControl,
+        Control, ControlParser, ControlType, CriticalControl, IntoRawControlVec, MakeCritical,
+        RawControl,
     };
     pub use crate::controls_impl::{
         EntryState, RefreshMode, SyncDone, SyncInfo, SyncRequest, SyncState,
